==> yabause_0.9.6.orig.tar.gz: yabause-0.9.6/src/windows/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by resource.rc
//
#define IDR_MENU                        100
#define IDI_ICON                        101
#define IDB_BITMAP                      102
#define IDR_MAIN_ACCEL                  103
#define IDD_MEMTRANSFER                 104
#define IDD_MEM                         105
#define IDD_SH2DEBUG                    106
#define IDD_VDP1DEBUG                   107
#define IDD_VDP2DEBUG                   108
#define IDD_M68KDEBUG                   109
#define IDD_SCUDSPDEBUG                 110
#define IDD_SCSPDEBUG                   111
#define IDD_GOTOADDRESS                 112
#define IDD_SEARCHMEMORY                113
#define IDD_SEARCHBUSY                  114
#define IDD_MEMORYEDITOR                115
#define IDD_SETTINGS                    116
#define IDD_BASICSETTINGS               117
#define IDD_VIDEOSETTINGS               118
#define IDD_SOUNDSETTINGS               119
#define IDD_NETLINKSETTINGS             120
#define IDD_INPUTSETTINGS               121
#define IDD_PADCONFIG                   122
#define IDD_BUTTONCONFIG                123
#define IDD_LOGSETTINGS                 124
#define IDD_ADDARCODE                   125
#define IDD_ADDCODE                     126
#define IDD_CHEATLIST                   127
#define IDD_CHEATSEARCH                 128
#define IDD_LOG                         129
#define IDD_BACKUPRAM                   130
#define IDD_ERRORDEBUG                  131
#define IDD_ABOUT                       132
#define IDD_SMPCDEBUG                   133
#define IDD_DIALOG1                     134
#define IDD_VDP2VIEWER                  134
#define IDC_EDITTEXT1                   1001
#define IDC_DISCTYPECB                  1001
#define IDC_VIDEOCORECB                 1001
#define IDC_SOUNDCORECB                 1001
#define IDC_LOCALREMOTEIP               1001
#define IDC_PAD1PB                      1001
#define IDC_USELOGCB                    1001
#define IDC_LOGET                       1001
#define IDC_VDP1CMDLB                   1001
#define IDC_NBG0ENABCB                  1001
#define IDC_SCSPSLOTCB                  1001
#define IDC_HEXEDIT                     1001
#define IDC_SPECIFYADDRRB               1001
#define IDC_SEARCHTYPECB                1001
#define IDC_BUPDEVICECB                 1001
#define IDC_CHEATLIST                   1001
#define IDC_EDTEXT                      1001
#define IDC_VERSIONTEXT                 1001
#define IDC_EDITTEXT2                   1002
#define IDC_DRIVELETTERCB               1002
#define IDC_FULLSCREENSTARTUPCB         1002
#define IDC_SLVOLUME                    1002
#define IDC_PORTET                      1002
#define IDC_PAD2PB                      1002
#define IDC_LOGTYPECB                   1002
#define IDC_SAVELOGBT                   1002
#define IDC_VDP1CMDET                   1002
#define IDC_NBG0ET                      1002
#define IDC_SCSPSLOTET                  1002
#define IDC_GOTOADDRESS                 1002
#define IDC_PRESETADDRRB                1002
#define IDC_SEARCHMEMET                 1002
#define IDC_BUPSAVELB                   1002
#define IDC_DELETECODE                  1002
#define IDC_EXACTRB                     1002
#define IDC_EDCONTINUE                  1002
#define IDC_EDITTEXT3                   1003
#define IDC_IMAGEEDIT                   1003
#define IDC_AUTOFRAMESKIPCB             1003
#define IDC_LOGFILENAMEET               1003
#define IDC_CLEARBT                     1003
#define IDC_VDP1TEXTET                  1003
#define IDC_NBG1ENABCB                  1003
#define IDC_SCSPSLOTSAVE                1003
#define IDC_SAVESEL                     1003
#define IDC_OFFSETET                    1003
#define IDC_SEARCHPB                    1003
#define IDC_BUPFREESPACELT              1003
#define IDC_CLEARCODES                  1003
#define IDC_LESSTHANRB                  1003
#define IDC_EDDEBUG                     1003
#define IDC_LISTBOX1                    1004
#define IDC_IMAGEBROWSE                 1004
#define IDC_FSSIZECB                    1004
#define IDC_LOGBROWSEBT                 1004
#define IDC_NBG1ET                      1004
#define IDC_SCSPSLOTREGSAVE             1004
#define IDC_SEARCHMEM                   1004
#define IDC_PRESETLISTCB                1004
#define IDC_SEARCHSTARTADDRET           1004
#define IDC_BUPDELETEBT                 1004
#define IDC_ADDAR                       1004
#define IDC_GREATERTHANRB               1004
#define IDC_LISTBOX2                    1005
#define IDC_SH2CORECB                   1005
#define IDC_CUSTOMWINDOWCB              1005
#define IDC_NBG2ENABCB                  1005
#define IDC_SCSPCOMMONREGET             1005
#define IDC_SEARCHENDADDRET             1005
#define IDC_BUPFORMATBT                 1005
#define IDC_ADDRAWMEMADDR               1005
#define IDC_LISTBOX3                    1006
#define IDC_REGIONCB                    1006
#define IDC_WIDTHEDIT                   1006
#define IDC_NBG2ET                      1006
#define IDC_BUPIMPORTBT                 1006
#define IDC_ADDFROMFILE                 1006
#define IDC_LISTBOX4                    1007
#define IDC_BIOSEDIT                    1007
#define IDC_HEIGHTEDIT                  1007
#define IDC_NBG3ENABCB                  1007
#define IDC_BUPEXPORTBT                 1007
#define IDC_MEMBPLB                     1007
#define IDC_CHECKBOX1                   1008
#define IDC_BIOSBROWSE                  1008
#define IDC_NBG3ET                      1008
#define IDC_BUPFILENAMEET               1008
#define IDC_CHECKBOX2                   1009
#define IDC_BACKUPRAMEDIT               1009
#define IDC_RBG0ENABCB                  1009
#define IDC_BUPCOMMENTET                1009
#define IDC_CHECKBOX3                   1010
#define IDC_BACKUPRAMBROWSE             1010
#define IDC_DXDEVICECB                  1010
#define IDC_RBG0ET                      1010
#define IDC_BUPLANGUAGEET               1010
#define IDC_CODE                        1010
#define IDC_UNSIGNEDRB                  1010
#define IDC_CHECKBOX4                   1011
#define IDC_MPEGROMEDIT                 1011
#define IDC_UPPB                        1011
#define IDC_BUPDATEET                   1011
#define IDC_CODEDESC                    1011
#define IDC_SIGNEDRB                    1011
#define IDC_DISPENABCB                  1011
#define IDC_CHECKBOX5                   1012
#define IDC_MPEGROMBROWSE               1012
#define IDC_DOWNPB                      1012
#define IDC_BUPDATASIZEET               1012
#define IDC_CODEADDR                    1012
#define IDC_CARTTYPECB                  1013
#define IDC_LEFTPB                      1013
#define IDC_BUPBLOCKSIZEET              1013
#define IDC_CODEVAL                     1013
#define IDC_CARTEDIT                    1014
#define IDC_RIGHTPB                     1014
#define IDC_VDP2GENET                   1014
#define IDC_CARTBROWSE                  1015
#define IDC_APB                         1015
#define IDC_CTENABLE                    1015
#define IDC_8BITRB                      1015
#define IDC_BPB                         1016
#define IDC_CTBYTEWRITE                 1016
#define IDC_16BITRB                     1016
#define IDC_CPB                         1017
#define IDC_CTWORDWRITE                 1017
#define IDC_32BITRB                     1017
#define IDC_XPB                         1018
#define IDC_CTLONGWRITE                 1018
#define IDC_YPB                         1019
#define IDC_STATUSBAR                   1020
#define IDC_SETTINGSTAB                 1020
#define IDC_ZPB                         1020
#define IDC_CHEATSEARCHET               1020
#define IDC_LPB                         1021
#define IDC_CTSEARCHRESTARTBT           1021
#define IDC_RPB                         1022
#define IDC_CTSEARCHBT                  1022
#define IDC_STARTPB                     1023
#define IDC_CTADDCHEATBT                1023
#define IDC_UPTEXT                      1024
#define IDC_STEP                        1025
#define IDC_DOWNTEXT                    1025
#define IDC_STEPOVER                    1026
#define IDC_LEFTTEXT                    1026
#define IDC_MEMTRANSFER                 1027
#define IDC_RIGHTTEXT                   1027
#define IDC_MEMEDITOR                   1028
#define IDC_ATEXT                       1028
#define IDC_BTEXT                       1029
#define IDC_CTEXT                       1030
#define IDC_XTEXT                       1031
#define IDC_YTEXT                       1032
#define IDC_ZTEXT                       1033
#define IDC_LTEXT                       1034
#define IDC_RTEXT                       1035
#define IDC_STARTTEXT                   1036
#define IDC_CUSTOMCANCEL                1037
#define IDC_ADDBP1                      1040
#define IDC_DELBP1                      1041
#define IDC_ADDBP2                      1042
#define IDC_ADDMEMBP                    1042
#define IDC_DELBP2                      1043
#define IDC_DELMEMBP                    1043
#define IDC_CHKREAD                     1044
#define IDC_CHKWRITE                    1045
#define IDC_CHKBYTE1                    1046
#define IDC_CHKWORD1                    1047
#define IDC_CHKLONG1                    1048
#define IDC_CHKBYTE2                    1049
#define IDC_CHKWORD2                    1050
#define IDC_CHKLONG2                    1051
#define IDC_BROWSE                      1060
#define IDC_DOWNLOADMEM                 1061
#define IDC_UPLOADMEM                   1062
#define IDC_PORT1CONNTYPECB             1064
#define IDC_PORT2CONNTYPECB             1065
#define IDC_PORT1ATYPECB                1066
#define IDC_PORT1BTYPECB                1067
#define IDC_PORT1CTYPECB                1068
#define IDC_PORT1DTYPECB                1069
#define IDC_PORT1ETYPECB                1070
#define IDC_PORT1FTYPECB                1071
#define IDC_PORT2ATYPECB                1072
#define IDC_PORT2BTYPECB                1073
#define IDC_PORT2CTYPECB                1074
#define IDC_PORT2DTYPECB                1075
#define IDC_PORT2ETYPECB                1076
#define IDC_PORT2FTYPECB                1077
#define IDC_PORT1ACFGPB                 1078
#define IDC_PORT1BCFGPB                 1079
#define IDC_PORT1CCFGPB                 1080
#define IDC_PORT1DCFGPB                 1081
#define IDC_PORT1ECFGPB                 1082
#define IDC_PORT1FCFGPB                 1083
#define IDC_PORT2ACFGPB                 1084
#define IDC_PORT2BCFGPB                 1085
#define IDC_PORT2CCFGPB                 1086
#define IDC_PORT2DCFGPB                 1087
#define IDC_PORT2ECFGPB                 1088
#define IDC_PORT2FCFGPB                 1089
#define IDC_REGLISTLB                   1099
#define IDC_DISASM                      1100
#define IDC_CODEBPET                    1101
#define IDC_CODEBPLB                    1102
#define IDC_ADDCODEBP                   1103
#define IDC_DELCODEBP                   1104
#define IDC_MEMBPET                     1105
#define IDC_CUSTOM1                     1106
#define IDC_BUTTON1                     1107
#define IDC_SAVETOFILE                  1107
#define IDC_VDP2VIEWER                  1107
#define IDC_VDP2SAVEBMPBT               1107
#define IDC_VDP2SCREENCB                1108
#define IDC_VDP2TEXTET                  1109
#define IDC_VDP1SAVEBMPBT               1110
#define IDM_CHOOSEBIOS                  40001
#define IDM_CHOOSECDROM                 40002
#define IDM_MEMTRANSFER                 40004
#define IDM_RUN                         40005
#define IDM_PAUSE                       40006
#define IDM_RESET                       40007
#define IDM_BACKUPRAMMANAGER            40008
#define IDM_SETTINGS                    40009
#define IDM_SAVESTATEAS                 40010
#define IDM_LOADSTATEAS                 40011
#define IDM_EXIT                        40012
#define IDM_CHEATSEARCH                 40020
#define IDM_CHEATLIST                   40021
#define IDM_MSH2DEBUG                   40030
#define IDM_SSH2DEBUG                   40031
#define IDM_VDP1DEBUG                   40032
#define IDM_VDP2DEBUG                   40033
#define IDM_M68KDEBUG                   40034
#define IDM_SCUDSPDEBUG                 40035
#define IDM_SCSPDEBUG                   40036
#define IDM_SMPCDEBUG                   40037
#define IDM_MEMORYEDITOR                40038
#define IDM_TOGGLEFULLSCREEN            40040
#define IDM_TOGGLENBG0                  40041
#define IDM_TOGGLENBG1                  40042
#define IDM_TOGGLENBG2                  40043
#define IDM_TOGGLENBG3                  40044
#define IDM_TOGGLERBG0                  40045
#define IDM_TOGGLEVDP1                  40046
#define IDM_TOGGLEFPS                   40047
#define IDM_WEBSITE                     40050
#define IDM_FORUM                       40051
#define IDM_SUBMITBUGREPORT             40052
#define IDM_DONATE                      40053
#define IDM_COMPATLIST                  40054
#define IDM_ABOUT                       40055
#define IDM_SAVESTATE_F2                40060
#define IDM_SAVESTATE_F3                40061
#define IDM_SAVESTATE_F4                40062
#define IDM_SAVESTATE_F5                40063
#define IDM_SAVESTATE_F6                40064
#define IDM_SAVESTATE_F7                40065
#define IDM_SAVESTATE_F8                40066
#define IDM_SAVESTATE_F9                40067
#define IDM_SAVESTATE_F10               40068
#define IDM_LOADSTATE_F2                40069
#define IDM_LOADSTATE_F3                40070
#define IDM_LOADSTATE_F4                40071
#define IDM_LOADSTATE_F5                40072
#define IDM_LOADSTATE_F6                40073
#define IDM_LOADSTATE_F7                40074
#define IDM_LOADSTATE_F8                40075
#define IDM_LOADSTATE_F9                40076
#define IDM_LOADSTATE_F10               40077
#define IDM_CAPTURESCREEN               40080
#define IDM_HARDRESET                   40081
#define IDC_INPUTREGLB                  40082
#define IDC_OUTPUTREGLB                 40083
#define IDC_SMPCSTATUSET                40084
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        135
#define _APS_NEXT_COMMAND_VALUE         40085
#define _APS_NEXT_CONTROL_VALUE         1111
#define _APS_NEXT_SYMED_VALUE           133
#endif
#endif

==> yabause_0.9.8.orig.tar.gz: yabause-0.9.8/src/windows/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by resource.rc
//
#define IDR_MENU                        100
#define IDI_ICON                        101
#define IDB_BITMAP                      102
#define IDR_MAIN_ACCEL                  103
#define IDD_MEMTRANSFER                 104
#define IDD_MEM                         105
#define IDD_SH2DEBUG                    106
#define IDD_VDP1DEBUG                   107
#define IDD_VDP2DEBUG                   108
#define IDD_M68KDEBUG                   109
#define IDD_SCUDSPDEBUG                 110
#define IDD_SCSPDEBUG                   111
#define IDD_GOTOADDRESS                 112
#define IDD_SEARCHMEMORY                113
#define IDD_SEARCHBUSY                  114
#define IDD_MEMORYEDITOR                115
#define IDD_SETTINGS                    116
#define IDD_BASICSETTINGS               117
#define IDD_VIDEOSETTINGS               118
#define IDD_SOUNDSETTINGS               119
#define IDD_NETLINKSETTINGS             120
#define IDD_INPUTSETTINGS               121
#define IDD_PADCONFIG                   122
#define IDD_BUTTONCONFIG                123
#define IDD_LOGSETTINGS                 124
#define IDD_ADDARCODE                   125
#define IDD_ADDCODE                     126
#define IDD_CHEATLIST                   127
#define IDD_CHEATSEARCH                 128
#define IDD_LOG                         129
#define IDD_BACKUPRAM                   130
#define IDD_ERRORDEBUG                  131
#define IDD_ABOUT                       132
#define IDD_SMPCDEBUG                   133
#define IDD_DIALOG1                     134
#define IDD_VDP2VIEWER                  134
#define IDD_PADCONFIG1                  135
#define IDD_MOUSECONFIG                 135
#define IDC_EDITTEXT1                   1001
#define IDC_DISCTYPECB                  1001
#define IDC_VIDEOCORECB                 1001
#define IDC_SOUNDCORECB                 1001
#define IDC_LOCALREMOTEIP               1001
#define IDC_PAD1PB                      1001
#define IDC_USELOGCB                    1001
#define IDC_LOGET                       1001
#define IDC_VDP1CMDLB                   1001
#define IDC_NBG0ENABCB                  1001
#define IDC_SCSPSLOTCB                  1001
#define IDC_HEXEDIT                     1001
#define IDC_SPECIFYADDRRB               1001
#define IDC_SEARCHTYPECB                1001
#define IDC_BUPDEVICECB                 1001
#define IDC_CHEATLIST                   1001
#define IDC_EDTEXT                      1001
#define IDC_VERSIONTEXT                 1001
#define IDC_WAITINPUT                   1001
#define IDC_EDITTEXT2                   1002
#define IDC_DRIVELETTERCB               1002
#define IDC_FULLSCREENSTARTUPCB         1002
#define IDC_SLVOLUME                    1002
#define IDC_PORTET                      1002
#define IDC_PAD2PB                      1002
#define IDC_LOGTYPECB                   1002
#define IDC_SAVELOGBT                   1002
#define IDC_VDP1CMDET                   1002
#define IDC_NBG0ET                      1002
#define IDC_SCSPSLOTET                  1002
#define IDC_GOTOADDRESS                 1002
#define IDC_PRESETADDRRB                1002
#define IDC_SEARCHMEMET                 1002
#define IDC_BUPSAVELB                   1002
#define IDC_DELETECODE                  1002
#define IDC_EXACTRB                     1002
#define IDC_EDCONTINUE                  1002
#define IDC_EDITTEXT3                   1003
#define IDC_IMAGEEDIT                   1003
#define IDC_AUTOFRAMESKIPCB             1003
#define IDC_LOGFILENAMEET               1003
#define IDC_CLEARBT                     1003
#define IDC_VDP1TEXTET                  1003
#define IDC_NBG1ENABCB                  1003
#define IDC_SCSPSLOTSAVE                1003
#define IDC_SAVESEL                     1003
#define IDC_OFFSETET                    1003
#define IDC_SEARCHPB                    1003
#define IDC_BUPFREESPACELT              1003
#define IDC_CLEARCODES                  1003
#define IDC_LESSTHANRB                  1003
#define IDC_EDDEBUG                     1003
#define IDC_LISTBOX1                    1004
#define IDC_IMAGEBROWSE                 1004
#define IDC_FSSIZECB                    1004
#define IDC_LOGBROWSEBT                 1004
#define IDC_NBG1ET                      1004
#define IDC_SCSPSLOTREGSAVE             1004
#define IDC_SEARCHMEM                   1004
#define IDC_PRESETLISTCB                1004
#define IDC_SEARCHSTARTADDRET           1004
#define IDC_BUPDELETEBT                 1004
#define IDC_ADDAR                       1004
#define IDC_GREATERTHANRB               1004
#define IDC_LISTBOX2                    1005
#define IDC_SH2CORECB                   1005
#define IDC_CUSTOMWINDOWCB              1005
#define IDC_NBG2ENABCB                  1005
#define IDC_SCSPCOMMONREGET             1005
#define IDC_SEARCHENDADDRET             1005
#define IDC_BUPFORMATBT                 1005
#define IDC_ADDRAWMEMADDR               1005
#define IDC_LISTBOX3                    1006
#define IDC_REGIONCB                    1006
#define IDC_WIDTHEDIT                   1006
#define IDC_NBG2ET                      1006
#define IDC_BUPIMPORTBT                 1006
#define IDC_ADDFROMFILE                 1006
#define IDC_LISTBOX4                    1007
#define IDC_BIOSEDIT                    1007
#define IDC_HEIGHTEDIT                  1007
#define IDC_NBG3ENABCB                  1007
#define IDC_BUPEXPORTBT                 1007
#define IDC_MEMBPLB                     1007
#define IDC_CHECKBOX1                   1008
#define IDC_BIOSBROWSE                  1008
#define IDC_NBG3ET                      1008
#define IDC_BUPFILENAMEET               1008
#define IDC_CHECKBOX2                   1009
#define IDC_BACKUPRAMEDIT               1009
#define IDC_RBG0ENABCB                  1009
#define IDC_BUPCOMMENTET                1009
#define IDC_CHECKBOX3                   1010
#define IDC_BACKUPRAMBROWSE             1010
#define IDC_DXDEVICECB                  1010
#define IDC_RBG0ET                      1010
#define IDC_BUPLANGUAGEET               1010
#define IDC_CODE                        1010
#define IDC_UNSIGNEDRB                  1010
#define IDC_CHECKBOX4                   1011
#define IDC_MPEGROMEDIT                 1011
#define IDC_UPPB                        1011
#define IDC_BUPDATEET                   1011
#define IDC_CODEDESC                    1011
#define IDC_SIGNEDRB                    1011
#define IDC_DISPENABCB                  1011
#define IDC_CHECKBOX5                   1012
#define IDC_MPEGROMBROWSE               1012
#define IDC_DOWNPB                      1012
#define IDC_BUPDATASIZEET               1012
#define IDC_CODEADDR                    1012
#define IDC_CARTTYPECB                  1013
#define IDC_LEFTPB                      1013
#define IDC_BUPBLOCKSIZEET              1013
#define IDC_CODEVAL                     1013
#define IDC_CARTEDIT                    1014
#define IDC_RIGHTPB                     1014
#define IDC_VDP2GENET                   1014
#define IDC_CARTBROWSE                  1015
#define IDC_APB                         1015
#define IDC_CTENABLE                    1015
#define IDC_8BITRB                      1015
#define IDC_BPB                         1016
#define IDC_CTBYTEWRITE                 1016
#define IDC_16BITRB                     1016
#define IDC_CPB                         1017
#define IDC_CTWORDWRITE                 1017
#define IDC_32BITRB                     1017
#define IDC_XPB                         1018
#define IDC_CTLONGWRITE                 1018
#define IDC_YPB                         1019
#define IDC_STATUSBAR                   1020
#define IDC_SETTINGSTAB                 1020
#define IDC_ZPB                         1020
#define IDC_CHEATSEARCHET               1020
#define IDC_LPB                         1021
#define IDC_CTSEARCHRESTARTBT           1021
#define IDC_RPB                         1022
#define IDC_CTSEARCHBT                  1022
#define IDC_STARTPB                     1023
#define IDC_CTADDCHEATBT                1023
#define IDC_UPTEXT                      1024
#define IDC_STEP                        1025
#define IDC_DOWNTEXT                    1025
#define IDC_STEPOVER                    1026
#define IDC_LEFTTEXT                    1026
#define IDC_MEMTRANSFER                 1027
#define IDC_RIGHTTEXT                   1027
#define IDC_MEMEDITOR                   1028
#define IDC_ATEXT                       1028
#define IDC_BTEXT                       1029
#define IDC_CTEXT                       1030
#define IDC_XTEXT                       1031
#define IDC_YTEXT                       1032
#define IDC_ZTEXT                       1033
#define IDC_LTEXT                       1034
#define IDC_RTEXT                       1035
#define IDC_STARTTEXT                   1036
#define IDC_CUSTOMCANCEL                1037
#define IDC_ADDBP1                      1040
#define IDC_DELBP1                      1041
#define IDC_ADDBP2                      1042
#define IDC_ADDMEMBP                    1042
#define IDC_DELBP2                      1043
#define IDC_DELMEMBP                    1043
#define IDC_CHKREAD                     1044
#define IDC_CHKWRITE                    1045
#define IDC_CHKBYTE1                    1046
#define IDC_CHKWORD1                    1047
#define IDC_CHKLONG1                    1048
#define IDC_CHKBYTE2                    1049
#define IDC_CHKWORD2                    1050
#define IDC_CHKLONG2                    1051
#define IDC_BROWSE                      1060
#define IDC_DOWNLOADMEM                 1061
#define IDC_UPLOADMEM                   1062
#define IDC_PORT1CONNTYPECB             1064
#define IDC_PORT2CONNTYPECB             1065
#define IDC_PORT1ATYPECB                1066
#define IDC_PORT1BTYPECB                1067
#define IDC_PORT1CTYPECB                1068
#define IDC_PORT1DTYPECB                1069
#define IDC_PORT1ETYPECB                1070
#define IDC_PORT1FTYPECB                1071
#define IDC_PORT2ATYPECB                1072
#define IDC_PORT2BTYPECB                1073
#define IDC_PORT2CTYPECB                1074
#define IDC_PORT2DTYPECB                1075
#define IDC_PORT2ETYPECB                1076
#define IDC_PORT2FTYPECB                1077
#define IDC_PORT1ACFGPB                 1078
#define IDC_PORT1BCFGPB                 1079
#define IDC_PORT1CCFGPB                 1080
#define IDC_PORT1DCFGPB                 1081
#define IDC_PORT1ECFGPB                 1082
#define IDC_PORT1FCFGPB                 1083
#define IDC_PORT2ACFGPB                 1084
#define IDC_PORT2BCFGPB                 1085
#define IDC_PORT2CCFGPB                 1086
#define IDC_PORT2DCFGPB                 1087
#define IDC_PORT2ECFGPB                 1088
#define IDC_PORT2FCFGPB                 1089
#define IDC_REGLISTLB                   1099
#define IDC_DISASM                      1100
#define IDC_CODEBPET                    1101
#define IDC_CODEBPLB                    1102
#define IDC_ADDCODEBP                   1103
#define IDC_DELCODEBP                   1104
#define IDC_MEMBPET                     1105
#define IDC_CUSTOM1                     1106
#define IDC_BUTTON1                     1107
#define IDC_SAVETOFILE                  1107
#define IDC_VDP2VIEWER                  1107
#define IDC_VDP2SAVEBMPBT               1107
#define IDC_VDP2SCREENCB                1108
#define IDC_VDP2TEXTET                  1109
#define IDC_VDP1SAVEBMPBT               1110
#define IDM_CHOOSEBIOS                  40001
#define IDM_CHOOSECDROM                 40002
#define IDM_MEMTRANSFER                 40004
#define IDM_RUN                         40005
#define IDM_PAUSE                       40006
#define IDM_RESET                       40007
#define IDM_BACKUPRAMMANAGER            40008
#define IDM_SETTINGS                    40009
#define IDM_SAVESTATEAS                 40010
#define IDM_LOADSTATEAS                 40011
#define IDM_EXIT                        40012
#define IDM_CHEATSEARCH                 40020
#define IDM_CHEATLIST                   40021
#define IDM_MSH2DEBUG                   40030
#define IDM_SSH2DEBUG                   40031
#define IDM_VDP1DEBUG                   40032
#define IDM_VDP2DEBUG                   40033
#define IDM_M68KDEBUG                   40034
#define IDM_SCUDSPDEBUG                 40035
#define IDM_SCSPDEBUG                   40036
#define IDM_SMPCDEBUG                   40037
#define IDM_MEMORYEDITOR                40038
#define IDM_TOGGLEFULLSCREEN            40040
#define IDM_TOGGLENBG0                  40041
#define IDM_TOGGLENBG1                  40042
#define IDM_TOGGLENBG2                  40043
#define IDM_TOGGLENBG3                  40044
#define IDM_TOGGLERBG0                  40045
#define IDM_TOGGLEVDP1                  40046
#define IDM_TOGGLEFPS                   40047
#define IDM_WEBSITE                     40050
#define IDM_FORUM                       40051
#define IDM_SUBMITBUGREPORT             40052
#define IDM_DONATE                      40053
#define IDM_COMPATLIST                  40054
#define IDM_ABOUT                       40055
#define IDM_SAVESTATE_F2                40060
#define IDM_SAVESTATE_F3                40061
#define IDM_SAVESTATE_F4                40062
#define IDM_SAVESTATE_F5                40063
#define IDM_SAVESTATE_F6                40064
#define IDM_SAVESTATE_F7                40065
#define IDM_SAVESTATE_F8                40066
#define IDM_SAVESTATE_F9                40067
#define IDM_SAVESTATE_F10               40068
#define IDM_LOADSTATE_F2                40069
#define IDM_LOADSTATE_F3                40070
#define IDM_LOADSTATE_F4                40071
#define IDM_LOADSTATE_F5                40072
#define IDM_LOADSTATE_F6                40073
#define IDM_LOADSTATE_F7                40074
#define IDM_LOADSTATE_F8                40075
#define IDM_LOADSTATE_F9                40076
#define IDM_LOADSTATE_F10               40077
#define IDM_CAPTURESCREEN               40080
#define IDM_HARDRESET                   40081
#define IDC_INPUTREGLB                  40082
#define IDC_OUTPUTREGLB                 40083
#define IDC_SMPCSTATUSET                40084
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        135
#define _APS_NEXT_COMMAND_VALUE         40085
#define _APS_NEXT_CONTROL_VALUE         1111
#define _APS_NEXT_SYMED_VALUE           133
#endif
#endif
